#ifndef MENU_INCLUDE
#define MENU_INCLUDE
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 M E N U   R O U T I N E S 
 
 presents the menu and its submenus.                                                                                                               
 Peter Beerli 1996, Seattle
 beerli@csit.fsu.edu
 
Copyright 2001 Peter Beerli and Joseph Felsenstein
 
$Id: menu.h,v 1.9 2003/11/04 16:12:09 beerli Exp $
-------------------------------------------------------*/

#include "migration.h"

extern void print_menu_title (FILE * file, option_fmt * options);
extern void print_menu_accratio (long a, long b, world_fmt *world);
extern long print_title (world_fmt * world, option_fmt * options);
extern void get_menu (option_fmt * options);

#endif /*MENU_INCLUDE */
